@@ -52,7 +52,7 @@ class TestPeriodogram(TestCase):
         assert_allclose(p, q/16.0)
 
     def test_integer_even(self):
-        x = np.zeros(16, dtype=np.int)
+        x = np.zeros(16, dtype=int)
         x[0] = 1
         f, p = periodogram(x)
         assert_allclose(f, np.linspace(0, 0.5, 9))
@@ -63,7 +63,7 @@ class TestPeriodogram(TestCase):
         assert_allclose(p, q)
 
     def test_integer_odd(self):
-        x = np.zeros(15, dtype=np.int)
+        x = np.zeros(15, dtype=int)
         x[0] = 1
         f, p = periodogram(x)
         assert_allclose(f, np.arange(8.0)/15.0)
@@ -73,7 +73,7 @@ class TestPeriodogram(TestCase):
         assert_allclose(p, q, atol=1e-15)
 
     def test_integer_twosided(self):
-        x = np.zeros(16, dtype=np.int)
+        x = np.zeros(16, dtype=int)
         x[0] = 1
         f, p = periodogram(x, return_onesided=False)
         assert_allclose(f, fftpack.fftfreq(16, 1.0))
@@ -117,8 +117,8 @@ class TestPeriodogram(TestCase):
     def test_window_external(self):
         x = np.zeros(16)
         x[0] = 1
-        f, p = periodogram(x, 10, 'hanning')
-        win = signal.get_window('hanning', 16)
+        f, p = periodogram(x, 10, 'hann')
+        win = signal.get_window('hann', 16)
         fe, pe = periodogram(x, 10, win)
         assert_array_almost_equal_nulp(p, pe)
         assert_array_almost_equal_nulp(f, fe)
@@ -257,7 +257,7 @@ class TestWelch(TestCase):
         assert_allclose(p, q, atol=1e-7, rtol=1e-7)
 
     def test_integer_onesided_even(self):
-        x = np.zeros(16, dtype=np.int)
+        x = np.zeros(16, dtype=int)
         x[0] = 1
         x[8] = 1
         f, p = welch(x, nperseg=8)
@@ -267,7 +267,7 @@ class TestWelch(TestCase):
         assert_allclose(p, q, atol=1e-7, rtol=1e-7)
 
     def test_integer_onesided_odd(self):
-        x = np.zeros(16, dtype=np.int)
+        x = np.zeros(16, dtype=int)
         x[0] = 1
         x[8] = 1
         f, p = welch(x, nperseg=9)
@@ -277,7 +277,7 @@ class TestWelch(TestCase):
         assert_allclose(p, q, atol=1e-7, rtol=1e-7)
 
     def test_integer_twosided(self):
-        x = np.zeros(16, dtype=np.int)
+        x = np.zeros(16, dtype=int)
         x[0] = 1
         x[8] = 1
         f, p = welch(x, nperseg=8, return_onesided=False)
@@ -355,8 +355,8 @@ class TestWelch(TestCase):
         x = np.zeros(16)
         x[0] = 1
         x[8] = 1
-        f, p = welch(x, 10, 'hanning', 8)
-        win = signal.get_window('hanning', 8)
+        f, p = welch(x, 10, 'hann', 8)
+        win = signal.get_window('hann', 8)
         fe, pe = welch(x, 10, win, 8)
         assert_array_almost_equal_nulp(p, pe)
         assert_array_almost_equal_nulp(f, fe)
@@ -404,7 +404,7 @@ class TestWelch(TestCase):
         assert_allclose(p, q, atol=1e-12)
 
     def test_bad_noverlap(self):
-        assert_raises(ValueError, welch, np.zeros(4), 1, 'hanning', 2, 7)
+        assert_raises(ValueError, welch, np.zeros(4), 1, 'hann', 2, 7)
 
     def test_nfft_too_short(self):
         assert_raises(ValueError, welch, np.ones(12), nfft=3, nperseg=4)
@@ -539,7 +539,7 @@ class TestCSD:
         assert_allclose(p, q, atol=1e-7, rtol=1e-7)
 
     def test_integer_onesided_even(self):
-        x = np.zeros(16, dtype=np.int)
+        x = np.zeros(16, dtype=int)
         x[0] = 1
         x[8] = 1
         f, p = csd(x, x, nperseg=8)
@@ -549,7 +549,7 @@ class TestCSD:
         assert_allclose(p, q, atol=1e-7, rtol=1e-7)
 
     def test_integer_onesided_odd(self):
-        x = np.zeros(16, dtype=np.int)
+        x = np.zeros(16, dtype=int)
         x[0] = 1
         x[8] = 1
         f, p = csd(x, x, nperseg=9)
@@ -559,7 +559,7 @@ class TestCSD:
         assert_allclose(p, q, atol=1e-7, rtol=1e-7)
 
     def test_integer_twosided(self):
-        x = np.zeros(16, dtype=np.int)
+        x = np.zeros(16, dtype=int)
         x[0] = 1
         x[8] = 1
         f, p = csd(x, x, nperseg=8, return_onesided=False)
@@ -637,8 +637,8 @@ class TestCSD:
         x = np.zeros(16)
         x[0] = 1
         x[8] = 1
-        f, p = csd(x, x, 10, 'hanning', 8)
-        win = signal.get_window('hanning', 8)
+        f, p = csd(x, x, 10, 'hann', 8)
+        win = signal.get_window('hann', 8)
         fe, pe = csd(x, x, 10, win, 8)
         assert_array_almost_equal_nulp(p, pe)
         assert_array_almost_equal_nulp(f, fe)
@@ -707,7 +707,7 @@ class TestCSD:
         assert_allclose(p, q, atol=1e-12)
 
     def test_bad_noverlap(self):
-        assert_raises(ValueError, csd, np.zeros(4), np.ones(4), 1, 'hanning',
+        assert_raises(ValueError, csd, np.zeros(4), np.ones(4), 1, 'hann',
                       2, 7)
 
     def test_nfft_too_short(self):
